@@ -23,9 +23,12 @@ dirs = [
     # "/home/alan/Documents/dev/skeletons/data/2021_09_15_1_Raf_06/2021_09_15_1_Raf_06/",
     # "/home/alan/Documents/dev/skeletons/data/2021_08_24_2Raf_00/2021_08_24_2Raf_00/",
     # "/home/alan/Documents/dev/skeletons/data/2021_11_01_01_Raf_00/2021_11_01_01_Raf_00/",
-    # "/home/alan/Documents/dev/skeletons/data/2020_10_23_downUpshift_2_0_2_glu_dual_phluorin__glt1_psa1_ura7__twice__04/2020_10_23_downUpshift_2_0_2_glu_dual_phluorin__glt1_psa1_ura7__twice__04"
-    "/home/alan/Documents/dev/skeletons/data/2021_11_05_wt_bs2_bs3_00/2021_11_05_wt_bs2_bs3_00/"
+    "/home/alan/Documents/dev/skeletons/data/2020_10_23_downUpshift_2_0_2_glu_dual_phluorin__glt1_psa1_ura7__twice__04/2020_10_23_downUpshift_2_0_2_glu_dual_phluorin__glt1_psa1_ura7__twice__04"
+    # "/home/alan/Documents/dev/skeletons/data/2021_11_05_wt_bs2_bs3_00/2021_11_05_wt_bs2_bs3_00/"
 ]
+# outdir = "/home/alan/Documents/dev/skeletons/data"
+# dirs = Path(outdir).glob("*ph*")
+
 import h5py
 
 from abc import abstractclassmethod, abstractmethod
@@ -464,12 +467,15 @@ class PageOrganiser(object):
 
 # for dir in dirs:
 #     print(f"Compiling {dir}")
-#     fullpath = Path("/home/alan/Documents/dev/skeletons/data/") / dir / dir
-#     compiler = ExperimentCompiler(None, fullpath)
-#     tmp = compiler.run()
-#     po = PageOrganiser(tmp, grid_spec=(3, 2))
-#     po.plot()
-#     po.save(fullpath / f"{dir.rstrip('/')}_report.pdf")
+#     try:
+#         fullpath = Path("/home/alan/Documents/dev/skeletons/data/") / dir / dir
+#         compiler = ExperimentCompiler(None, fullpath)
+#         tmp = compiler.run()
+#         po = PageOrganiser(tmp, grid_spec=(3, 2))
+#         po.plot()
+#         po.save(fullpath / f"{dir.rstrip('/')}_report.pdf")
+#     except Exception as e:
+#         print(e)
 
 #### Live editing
 
